@@ -6,10 +6,11 @@ from ..parameters import ORG, APP_CODE
 from ..fabric import Fabric
 from ..parameters import APIREF, TEMP_DIR
 from ..lib import readSets
-from ..core.helpers import console, setDir, mergeDict
+from ..core.helpers import console, setDir, mergeDict, normpath, abspath, expanduser
 from .find import findAppConfig, findAppClass
 from .helpers import getText, dm, dh
 from .settings import setAppSpecs, setAppSpecsApi
+from .volumes import volumesApi
 from .links import linksApi, outLink
 from .text import textApi
 from .sections import sectionsApi
@@ -48,9 +49,11 @@ class App:
         hoist=False,
         version=None,
         checkout="",
-        mod=None,
+        mod=[],
         locations=None,
         modules=None,
+        volume=None,
+        collection=None,
         api=None,
         setFile="",
         silent=False,
@@ -131,14 +134,14 @@ class App:
                 Every properly designed data module must refer to a specific
                 version of the main source!
 
-        mod: string, optional `None`
-            A comma-separated list of modules in one of the forms
+        mod: string or iterable, optional `[]`
+            A comma-separated list or an iterable of modules in one of the forms
 
-               {org}/{repo}/{path}`
+               {org}/{repo}/{path}
 
             or
 
-               {org}/{repo}/{path}:specifier`
+               {org}/{repo}/{path}:specifier
 
             All features of all those modules will be loaded.
             If they are not yet present, they will be downloaded from GitHub first.
@@ -146,7 +149,7 @@ class App:
             For example, there is an easter egg module on GitHub,
             and you can obtain it by
 
-               mod='etcbc/lingo/easter/tf'`
+               mod='etcbc/lingo/easter/tf'
 
             Here the `{org}` is `etcbc`, the `{repo}` is `lingo`,
             and the `{path}` is `easter/tf` under which
@@ -162,6 +165,17 @@ class App:
             Your TF app might be configured to download specific modules.
             See `moduleSpecs` in the app's `config.yaml` file.
 
+            If you need these specific module with a different checkout specifier,
+            you can override those by passing those modules in this parameter
+            explicitly.
+
+            !!! hint
+                This is needed for example if you specify a specific release
+                for the core data module. The associated standard modules probably
+                do not have that exact same release, so you have to look up their
+                releases in Github, and attach the release numbers found
+                to the module specifiers.
+
             !!! caution "Let TF manage your text-fabric-data directory"
                 It is better not to fiddle with your `~/text-fabric-data` directory
                 manually. Let it be filled with auto-downloaded data.
@@ -186,6 +200,20 @@ class App:
                 It acts as the main `locations` argument,
                 and will be combined with the `modules` argument.
 
+        collection: string
+            Triggers the loading of a single collection of
+            volumes of the work. The collection is a directory with `.tf` files,
+            located under the directory `_local` which is in the
+            same directory as the `.tf` files of the work.
+            See `tf.about.volumes`.
+
+        volume: string
+            Triggers the loading of a single volume of
+            the work. The volume is a directory with `.tf` files,
+            located under the directory `_local` which is in the
+            same directory as the `.tf` files of the work.
+            See `tf.about.volumes`.
+
         api: object, optional, `None`
             So far, the TF app will construct an advanced API
             with a more or less standard set of features
@@ -238,6 +266,12 @@ class App:
             The list of those settings is spelled out in
             `tf.advanced.settings`.
 
+        !!! caution "Volumes and collections"
+            It is an error to load a volume as a collection and vice-versa
+
+            You get a warning if you pass both a volume and a collection.
+            The collection takes precedence, and the volume is ignored in that case.
+
         See Also
         --------
         tf.about.corpora: list of corpora with an official TF app
@@ -259,6 +293,8 @@ class App:
             appName=appName,
             api=api,
             version=version,
+            volume=volume,
+            collection=collection,
             silent=silent,
             _browse=_browse,
         ).items():
@@ -286,17 +322,23 @@ class App:
             if specs:
                 (locations, modules) = specs
                 self.tempDir = f"{self.repoLocation}/{TEMP_DIR}"
-                TF = Fabric(locations=locations, modules=modules, silent=silent or True)
-                api = TF.load("", silent=silent or True)
+                TF = Fabric(
+                    locations=locations,
+                    modules=modules,
+                    volume=volume,
+                    collection=collection,
+                    silent=silent,
+                )
+                api = TF.load("", silent=True)
                 if api:
                     self.api = api
                     excludedFeatures = aContext.excludedFeatures
-                    allFeatures = TF.explore(silent=silent or True, show=True)
+                    allFeatures = TF.explore(silent=True, show=True)
                     loadableFeatures = allFeatures["nodes"] + allFeatures["edges"]
                     useFeatures = [
                         f for f in loadableFeatures if f not in excludedFeatures
                     ]
-                    result = TF.load(useFeatures, add=True, silent=silent or True)
+                    result = TF.load(useFeatures, add=True, silent=True)
                     if result is False:
                         self.api = None
             else:
@@ -307,19 +349,25 @@ class App:
             for m in FROM_TF_METHODS:
                 setattr(self, m, getattr(self.TF, m))
             self.getText = types.MethodType(getText, self)
+            volumesApi(self)
             linksApi(self, silent)
             searchApi(self)
             sectionsApi(self)
             setAppSpecsApi(self, cfg)
             displayApi(self, silent)
             textApi(self)
+            setattr(self, "isLoaded", self.api.isLoaded)
             if hoist:
                 # docs = self.api.makeAvailableIn(hoist)
                 self.api.makeAvailableIn(hoist)
                 if not silent:
                     dh(
                         "<div><b>Text-Fabric API:</b> names "
-                        + outLink("N F E L T S C TF", APIREF, title="doc",)
+                        + outLink(
+                            "N F E L T S C TF",
+                            APIREF,
+                            title="doc",
+                        )
                         + " directly usable</div><hr>"
                     )
 
@@ -336,6 +384,35 @@ The app "{appName}" will not work!
                     error=True,
                 )
 
+    def load(self, features, silent=False):
+        """Loads extra features in addition to the main dataset.
+
+        This is the same as `tf.fabric.Fabric.load` when called with `add=True`.
+
+        Parameters
+        ----------
+        features: string | iterable
+            Either a string containing space separated feature names, or an
+            iterable of feature names.
+            The feature names are just the names of `.tf` files
+            without directory information and without extension.
+        silent: boolean, optional `None`
+            If `False`, the features will be loaded rather silently,
+            most messages will be suppressed.
+            Time consuming operations will always be announced,
+            so that you know what Text-Fabric is doing.
+            If `True` is passed, all informational messages will be suppressed.
+            This is handy I you want to load data as part of other methods, on-the-fly.
+
+        Returns
+        -------
+        boolean
+            Whether the feature has been successfully loaded.
+        """
+
+        TF = self.TF
+        return TF.load(features, add=True, silent=silent)
+
     def reinit(self):
         """TF-Apps may override this method.
         It is called by `reuse`. Hence it needs to be present.
@@ -429,9 +506,11 @@ def findApp(appName, checkoutApp, _browse, *args, silent=False, version=None, **
     (commit, release, local) = (None, None, None)
     extraMod = None
 
+    appName = normpath(appName)
+
     if not appName or ("/" in appName and checkoutApp == ""):
-        appPath = os.path.expanduser(appName) if appName else ""
-        absPath = os.path.abspath(appPath)
+        appPath = expanduser(appName) if appName else ""
+        absPath = abspath(appPath)
 
         if os.path.isdir(absPath):
             (appDir, appName) = os.path.split(absPath)
@@ -479,11 +558,15 @@ def findApp(appName, checkoutApp, _browse, *args, silent=False, version=None, **
         appPath = f"{appBaseRep}{appDir}"
 
         appClass = findAppClass(appName, appPath) or App
+
+    mod = kwargs.get("mod", [])
+    mod = mod.split(",") if type(mod) is str else list(mod)
     if extraMod:
-        if kwargs.get("mod", None):
-            kwargs["mod"] = f"{extraMod},{kwargs['mod']}"
+        if len(mod) > 0:
+            mod = [extraMod, *mod]
         else:
-            kwargs["mod"] = extraMod
+            mod = [extraMod]
+    kwargs["mod"] = mod
     try:
         app = appClass(
             cfg,
@@ -501,7 +584,8 @@ def findApp(appName, checkoutApp, _browse, *args, silent=False, version=None, **
     except Exception as e:
         if appClass is not App:
             console(
-                f"There was an error loading TF-app {appName} from {appPath}", error=True
+                f"There was an error loading TF-app {appName} from {appPath}",
+                error=True,
             )
             console(repr(e), error=True)
         traceback.print_exc()
