@@ -3,9 +3,13 @@ import os
 from IPython.display import display, Markdown, HTML
 
 from ..parameters import EXPRESS_BASE, GH_BASE, TEMP_DIR
-from ..core.helpers import mdEsc, htmlEsc, unexpanduser, QUAD
+from ..core.helpers import mdEsc, htmlEsc, expanduser, unexpanduser, QUAD
+from ..core.text import DEFAULT_FORMAT
 
 
+NORMAL = "normal"
+ORIG = "orig"
+
 RESULT = "result"
 NB = "\u00a0"
 EM = "*empty*"
@@ -14,6 +18,19 @@ SEQ_TYPES1 = {tuple, list}
 SEQ_TYPES2 = {tuple, list, set, frozenset}
 
 
+def _getLtr(app, options):
+    aContext = app.context
+    direction = aContext.direction
+
+    fmt = options.fmt or DEFAULT_FORMAT
+
+    return (
+        "rtl"
+        if direction == "rtl" and (f"{ORIG}-" in fmt or f"-{ORIG}" in fmt)
+        else ("" if direction == "ltr" else "ltr")
+    )
+
+
 def dm(md):
     """Display markdown in a Jupyter notebook.
 
@@ -62,18 +79,18 @@ def getLocalDir(cfg, local, version):
     if not base:
         base = EXPRESS_BASE
 
-    return os.path.expanduser(f"{base}/{org}/{repo}/{TEMP_DIR}")
+    return expanduser(f"{base}/{org}/{repo}/{TEMP_DIR}")
 
 
 def hasData(local, org, repo, version, relative):
     versionRep = f"/{version}" if version else ""
     if local == "clone":
-        ghBase = os.path.expanduser(GH_BASE)
+        ghBase = expanduser(GH_BASE)
         ghTarget = f"{ghBase}/{org}/{repo}/{relative}{versionRep}"
         if os.path.exists(ghTarget):
             return ghBase
 
-    expressBase = os.path.expanduser(EXPRESS_BASE)
+    expressBase = expanduser(EXPRESS_BASE)
     expressTarget = f"{expressBase}/{org}/{repo}/{relative}{versionRep}"
     if os.path.exists(expressTarget):
         return expressBase
@@ -204,6 +221,9 @@ def htmlSafe(text, isHtml):
 def getText(
     app, isPretty, n, nType, outer, first, last, level, passage, descend, options=None
 ):
+    display = app.display
+    dContext = display.distill(options or {})
+    ltr = _getLtr(app, dContext) or "ltr"
     T = app.api.T
     sectionTypeSet = T.sectionTypeSet
     structureTypeSet = T.structureTypeSet
@@ -221,9 +241,9 @@ def getText(
     tplFilled = (
         (
             (
-                '<span class="tfsechead">'
+                f"""<span class="tfsechead {ltr}"><span class="ltr">"""
                 + (NB if passage else app.sectionStrFromNode(n))
-                + "</span>"
+                + "</span></span>"
             )
             if nType in sectionTypeSet
             else f'<span class="structure">{app.structureStrFromNode(n)}</span>'
