@@ -4,6 +4,7 @@ Produce links to Text-Fabric data and links from nodes to web resources.
 
 import re
 import types
+from textwrap import dedent
 
 from ..parameters import (
     URL_GH,
@@ -33,6 +34,12 @@ def linksApi(app, silent):
     It also computes several provenance and documentation links from the
     configuration settings of the corpus.
 
+
+    If a single volume has been loaded, there will be added a provenance notice
+    to the provenance data of the work as a whole,
+    essentially stating which volume from the work is being used and what top-level
+    sections of the work are part of it.
+
     Parameters
     ----------
     app: obj
@@ -52,7 +59,7 @@ def linksApi(app, silent):
     appPath = aContext.appPath
     apiVersion = aContext.apiVersion
     docUrl = aContext.docUrl
-    repo = aContext.repo
+    repo = aContext.repo or ""
     version = aContext.version
     corpus = aContext.corpus
     featureBase = aContext.featureBase
@@ -64,8 +71,17 @@ def linksApi(app, silent):
     extraUrl = f"{APP_URL}/app-{appName}"
     apiVersionRep = "" if apiVersion is None else f" v{apiVersion}"
 
+    dataName = repo.upper()
+    collectionInfo = app.collectionInfo
+    if collectionInfo:
+        dataName += f" collection {collectionInfo}"
+    else:
+        volumeInfo = app.volumeInfo
+        if volumeInfo:
+            dataName += f" volume {volumeInfo}"
+
     dataLink = (
-        outLink(repo.upper(), docUrl, f"provenance of {corpus}")
+        outLink(dataName, docUrl, f"provenance of {corpus}")
         if isCompatible and repo is not None and docUrl
         else "/".join(x for x in (appPath, appName, version) if x)
     )
@@ -219,6 +235,7 @@ def webLink(
     webLang = aContext.webLang
     webOffset = aContext.webOffset
     webUrl = aContext.webUrl
+    webUrlZeros = aContext.webUrlZeros or {}
     webUrlLex = aContext.webUrlLex
     webLexId = aContext.webLexId
     webHint = aContext.webHint
@@ -260,6 +277,10 @@ def webLink(
                     else defaultOffset
                 )
                 value = "" if heading is None else str(heading + offset)
+                leadingZeros = webUrlZeros.get(i + 1, 0)
+                if 0 < len(value) < leadingZeros:
+                    value = "0" * (leadingZeros - len(value)) + value
+
                 href = href.replace(f"<{i + 1}>", value)
         else:
             href = None
@@ -469,7 +490,12 @@ def _featuresPerModule(app):
                 if type(mId) is str
                 else f"{URL_GH}/{mId[0]}/{mId[1]}/tree/master/{mId[2]}"
             )
-        html += f"<details><summary><b>{corpus}</b></summary>"
+        html += dedent(
+            f"""
+            <details><summary><b>{corpus}</b></summary>
+                <div class="fcorpus">
+        """
+        )
 
         seen = set()
 
@@ -485,9 +511,19 @@ def _featuresPerModule(app):
             featureInfo = TF.features[feature]
             featurePath = ux(featureInfo.path)
             isEdge = featureInfo.isEdge
-            pre = "<b><i>" if isEdge else ""
-            post = "</i></b>" if isEdge else ""
-            html += f"{pre}"
+            valueType = featureInfo.dataType
+            edgeValues = featureInfo.edgeValues
+            typeRep = "none" if isEdge and not edgeValues else valueType
+            meta = featureInfo.metaData
+            description = meta.get("description", "")
+
+            edgeRep = "edge" if isEdge else ""
+            html += dedent(
+                f"""
+                    <div class="frow">
+                        <div class="fnamecat {edgeRep}">
+                """
+            )
             html += (
                 outLink(
                     featureRep,
@@ -497,8 +533,40 @@ def _featuresPerModule(app):
                 if docUrl
                 else f'<span title="{featurePath}">{featureRep}</span>'
             )
-            html += f"{post}<br>"
-        html += "</details>"
+            html += dedent(
+                f"""
+                        </div>
+                        <div class="fmono">{typeRep}</div>
+                        <details>
+                            <summary>{description}</summary>
+                            <div class="fmeta">
+                """
+            )
+            for (k, v) in sorted(meta.items()):
+                if k not in {"valueType", "description"}:
+                    k = htmlEsc(k)
+                    v = htmlEsc(v)
+                    html += dedent(
+                        f"""
+                            <div class="fmetarow">
+                                <div class="fmetakey">{k}:</div>
+                                <div>{v}</div>
+                            </div>
+                    """
+                    )
+            html += dedent(
+                """
+                            </div>
+                        </details>
+                    </div>
+                """
+            )
+        html += dedent(
+            """
+                </div>
+            </details>
+            """
+        )
     return html
 
 
