@@ -120,7 +120,7 @@ rm dataset ; mql -b 3 < dataset.mql
 import os
 import re
 from itertools import chain
-from ..core.data import WARP
+from ..parameters import WARP, OTYPE, OSLOTS
 from ..core.helpers import (
     cleanName,
     isClean,
@@ -129,6 +129,7 @@ from ..core.helpers import (
     setFromSpec,
     nbytes,
     console,
+    normpath,
 )
 
 # If a feature, with type string, has less than ENUM_LIMIT values,
@@ -144,6 +145,7 @@ class MQL(object):
     def __init__(self, mqlDir, mqlName, tfFeatures, tmObj):
         error = tmObj.error
 
+        mqlDir = normpath(mqlDir)
         self.mqlDir = mqlDir
         cleanDb = cleanName(mqlName)
         if cleanDb != mqlName:
@@ -214,7 +216,7 @@ class MQL(object):
             self.featureList.append(cleanF)
             self.features[cleanF] = fo
         good = True
-        for feat in (WARP[0], WARP[1], "__levels__"):
+        for feat in (OTYPE, OSLOTS, "__levels__"):
             if feat not in self.tfFeatures:
                 error(
                     "{} feature {} is missing from data set".format(
@@ -430,7 +432,7 @@ GO
                 len(self.levels),
             )
         )
-        oslotsData = self.tfFeatures[WARP[1]].data
+        oslotsData = self.tfFeatures[OSLOTS].data
         self.oslots = oslotsData[0]
         self.maxSlot = oslotsData[1]
         for (otype, av, start, end) in self.levels:
@@ -537,6 +539,16 @@ def uni(line):
 
 
 def tfFromMql(mqlFile, tmObj, slotType=None, otext=None, meta=None):
+    """Generate TF from MQL
+
+    Parameters
+    ----------
+    tmObj: object
+        A `tf.core.timestamp.Timestamp` object
+    mqlFile, slotType, otype, meta: various
+        See `tf.core.fabric.Fabric.importMQL
+    """
+    mqlFile = normpath(mqlFile)
     error = tmObj.error
 
     if slotType is None:
@@ -772,7 +784,12 @@ def tfFromData(tmObj, objectTypes, tables, nodeF, edgeF, slotType, otext, meta):
     metaData = dict()
 
     # metadata that ends up in every feature
-    metaData[""] = {} if meta is None else meta
+    metaData[""] = meta.get("", {})
+    distinctFeatures = chain(chain.from_iterable(nodeF.values()), chain.from_iterable(edgeF.values()))
+    for f in distinctFeatures:
+        metaInfo = meta.get(f, None)
+        if metaInfo is not None:
+            metaData[f] = metaInfo
 
     # the config feature otext
     metaData["otext"] = otext
