@@ -2,6 +2,49 @@ import os
 import sys
 import re
 
+from ..parameters import OMAP
+
+
+def normpath(path):
+    return path.replace("\\", "/")
+
+
+def abspath(path):
+    return normpath(os.path.abspath(path))
+
+
+def expanduser(path):
+    return normpath(os.path.expanduser(path))
+
+
+HOME_DIR = expanduser("~")
+
+
+def unexpanduser(path):
+    return normpath(path).replace(HOME_DIR, "~")
+
+
+def setDir(obj):
+    obj.homeDir = expanduser("~")
+    obj.curDir = normpath(os.getcwd())
+    (obj.parentDir, x) = os.path.split(obj.curDir)
+
+
+def expandDir(obj, dirName):
+    if dirName.startswith("~"):
+        dirName = dirName.replace("~", obj.homeDir, 1)
+    elif dirName.startswith(".."):
+        dirName = dirName.replace("..", obj.parentDir, 1)
+    elif dirName.startswith("."):
+        dirName = dirName.replace(".", obj.curDir, 1)
+    return dirName
+
+
+def dirEmpty(target):
+    target = normpath(target)
+    return not os.path.exists(target) or not os.listdir(target)
+
+
 LETTER = set("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ")
 VALID = set("_0123456789") | LETTER
 
@@ -12,23 +55,14 @@ Consider installing a 64-bit Python.
 
 MSG64 = """Running on 64-bit Python"""
 
-HOME_DIR = os.path.expanduser("~").replace("\\", "/")
-
-SEP_RE = re.compile(r"[ ,]+")
+SEP_RE = re.compile(r"[\n\t ,]+")
+STRIP_RE = re.compile(r"(?:^[\n\t ,]+)|(?:[\n\t ,]+$)", re.S)
 VAR_RE = re.compile(r"\{([^}]+?)(:[^}]+)?\}")
 MSG_LINE_RE = re.compile(r"^( *[0-9]+) (.*)$")
 
 QUAD = "  "
 
 
-def unexpanduser(path):
-    return path.replace(HOME_DIR, "~")
-
-
-def dirEmpty(target):
-    return not os.path.exists(target) or not os.listdir(target)
-
-
 def isInt(val):
     try:
         val = int(val)
@@ -172,22 +206,6 @@ def flattenToSet(features):
     return theseFeatures
 
 
-def setDir(obj):
-    obj.homeDir = os.path.expanduser("~").replace("\\", "/")
-    obj.curDir = os.getcwd().replace("\\", "/")
-    (obj.parentDir, x) = os.path.split(obj.curDir)
-
-
-def expandDir(obj, dirName):
-    if dirName.startswith("~"):
-        dirName = dirName.replace("~", obj.homeDir, 1)
-    elif dirName.startswith(".."):
-        dirName = dirName.replace("..", obj.parentDir, 1)
-    elif dirName.startswith("."):
-        dirName = dirName.replace(".", obj.curDir, 1)
-    return dirName
-
-
 def setFromSpec(spec):
     covered = set()
     for r_str in spec.split(","):
@@ -339,6 +357,16 @@ def itemize(string, sep=None):
     return string.strip().split(sep)
 
 
+def fitemize(value):
+    if not value:
+        return []
+    if type(value) is str:
+        return SEP_RE.split(STRIP_RE.sub("", value))
+    if type(value) in {bool, int, float}:
+        return [str(value)]
+    return list(str(v) for v in value)
+
+
 def project(iterableOfTuples, maxDimension):
     if maxDimension == 1:
         return {r[0] for r in iterableOfTuples}
@@ -414,3 +442,62 @@ def mergeDict(source, overrides):
             mergeDict(source[k], v)
         else:
             source[k] = v
+
+
+def getAllFeatures(api):
+    """Get all config features and all loaded node and edge features.
+
+    Except `omap@v-w` features.
+    When we take volumes or collections from works,
+    we need to pass these features on.
+
+    This will exclude the computed features and the node/edge features
+    that are not loaded by default.
+    """
+
+    TF = api.TF
+    allFeatures = set()
+
+    for (feat, fObj) in TF.features.items():
+        if fObj.method:
+            continue
+        if fObj.isConfig:
+            allFeatures.add(feat)
+
+    allFeatures |= set(api.Fall())
+    allFeatures |= set(e for e in api.Eall() if not e.startswith(OMAP))
+    return allFeatures
+
+
+def formatMeta(featureMeta):
+    """Reorder meta data.
+
+    Parameters
+    ----------
+    meta: dict
+        Dictionary of meta data: keyed by feature, valued by a dict
+        of metadata in the form of key values
+
+    Returns
+    -------
+    dict
+        A copy of the dict but with the values for metadata keys
+        `desc` and `eg` merged under a new key `description`,
+        and the keys `desc` and `eg` deleted.
+    """
+
+    result = {}
+    for (f, meta) in featureMeta.items():
+        fmeta = {}
+        for (k, v) in meta.items():
+            if k == "eg" and "desc" in meta:
+                continue
+            if k == "desc":
+                eg = meta.get("eg", "")
+                egRep = f" ({eg})" if eg else ""
+                fmeta["description"] = f"{v}{egRep}"
+            else:
+                fmeta[k] = v
+        result[f] = fmeta
+
+    return result
