@@ -6,7 +6,7 @@ The precomputed data has a similar function as indexes in a database.
 
 Precomputation is triggered when `tf.fabric.Fabric` loads features, and
 the order and nature of the steps is configured in
-`tf.fabric.PRECOMPUTE`.
+`tf.core.fabric.PRECOMPUTE`.
 
 The functions in this module implement those tasks.
 """
@@ -526,6 +526,7 @@ def sections(info, error, otype, oslots, otext, levUp, levels, *sFeats):
                 nestingProblems[
                     f"section {sTypes[2]} without containing {sTypes[1]}"
                 ] += 1
+                print(f"{sTypes[2]} {n2} without containing {sTypes[1]}")
                 continue
             n1 = n1s[0]
             n1s = sFeats[1][n1]
