@@ -8,7 +8,7 @@ import sys
 from zipfile import ZIP_DEFLATED
 
 
-VERSION = '8.5.14'
+VERSION = '9.1.9'
 """Program version.
 
 This value is under control of the update process, as run by
@@ -63,6 +63,48 @@ App requirement lower than TF API version
     downgrade Text-Fabric
 """
 
+OTYPE = "otype"
+"""Name of a central feature in a TF data set:
+`otype` maps nodes to their types."""
+
+OSLOTS = "oslots"
+"""Name of a central feature in a TF data set:
+`oslots` maps non-slot nodes to the sets of slots they occupy."""
+
+OTEXT = "otext"
+"""Name of a central (but optional) feature in a TF data set:
+`otext` has configuration settings for sections, structure, and text formats."""
+
+OVOLUME = "ovolume"
+"""Name of the feature that maps nodes of a work dataset
+to nodes in individual volumes in that work."""
+
+OWORK = "owork"
+"""Name of the feature that maps nodes in an individual volume of a work
+to nodes in that work."""
+
+OINTERF = "ointerfrom"
+"""Name of the feature that stores the outgoing inter-volume edges
+of a volume."""
+
+OINTERT = "ointerto"
+"""Name of the feature that stores the incoming inter-volume edges
+of a volume."""
+
+OMAP = "omap"
+"""Name prefix of features with a node map from an older version to a newer version.
+
+The full name of such a feature is `omap@`*oldversion*`-`*newversion*
+"""
+
+WARP = (OTYPE, OSLOTS, OTEXT)
+"""The names of the central features of TF data sets.
+
+The features `otype` and `oslots` are crucial to every TF dataset.
+Without them, a dataset is not a TF dataset, although it could still be a
+TF data module.
+"""
+
 GZIP_LEVEL = 2
 """Compression level when compressing tf files."""
 
@@ -181,13 +223,7 @@ TEMP_DIR = "_temp"
     in the `.gitignore` file.
 """
 
-LOCATIONS = [
-    "~/Downloads/text-fabric-data",
-    "~/text-fabric-data",
-    "~/github/text-fabric-data",
-    "~/Dropbox/text-fabric-data",
-    "/mnt/shared/text-fabric-data",
-]
+LOCATIONS = ["~/text-fabric-data"]
 """Default locations for tf data files.
 
 If the `locations` parameter for the `tf.fabric.Fabric` call is omitted,
@@ -195,6 +231,15 @@ this is the default.
 Text-Fabric will search all these directories as for `.tf` modules of files.
 """
 
+LOCAL = "_local"
+"""Name of auxiliary directories.
+
+Examples where this is used:
+
+*   volume support: inside a TF dataset, the directory `_local` contains
+    volumes of that dataset
+"""
+
 ZIP_OPTIONS = dict(compression=ZIP_DEFLATED)
 """Options for zip when packing tf files.
 
