@@ -8,17 +8,13 @@ import types
 import re
 from itertools import chain
 
-from ..core.data import WARP
+from ..parameters import OTYPE, OSLOTS
 from ..core.helpers import makeIndex
 from .syntax import reTp
 
 # LOW-LEVEL NODE RELATIONS SEMANTICS ###
 
 
-OTYPE = WARP[0]
-OSLOTS = WARP[1]
-
-
 def _l_em(n):
     return ()
 
@@ -1453,11 +1449,11 @@ def basicRelations(searchExe, api):
         ),
         (
             (".f>g.", 0.4, leftFgreaterRightGR, "left.f > right.g"),
-            (".g<f.", 0.4, leftGlesserRightFR, None),
+            (".f<g.", 0.4, leftFlesserRightGR, None),
         ),
         (
-            (".f<g.", 0.4, leftFlesserRightGR, "left.f > right.g"),
-            (".g>f.", 0.4, leftGgreaterRightFR, None),
+            (".f<g.", 0.4, leftFlesserRightGR, "left.f < right.g"),
+            (".f>g.", 0.4, leftFgreaterRightGR, None),
         ),
     ]
 
