@@ -1,5 +1,14 @@
 """
-.. include:: ../../docs/server/servelib.md
+# Common Server Related Functions
+
+## About
+
+Here are functions that are being used by various parts of the
+TF browser infrastructure, such as
+
+* `tf.server.kernel`
+* `tf.server.web`
+* `tf.server.start`
 """
 
 import json
@@ -124,7 +133,7 @@ Job: {form['jobName']}
 """
 
 
-def zipData(csvs, resultsX, about, form):
+def zipData(csvs, tupleResultsX, queryResultsX, about, form):
     appName = form["appName"]
     jobName = form["jobName"]
 
@@ -139,11 +148,14 @@ def zipData(csvs, resultsX, about, form):
                     ("\t".join(str(t) for t in tup) + "\n") for tup in data
                 )
                 zipFile.writestr(f"{csv}.tsv", contents.encode("utf8"))
-            for (name, data) in (("resultsx", resultsX),):
+            for (name, data) in (
+                ("nodesx.tsv", tupleResultsX),
+                ("resultsx.tsv", queryResultsX),
+            ):
                 if data is not None:
                     contents = "\ufeff" + "".join(
                         ("\t".join("" if t is None else str(t) for t in tup) + "\n")
                         for tup in data
                     )
-                    zipFile.writestr(f"resultsx.tsv", contents.encode("utf_16_le"))
+                    zipFile.writestr(name, contents.encode("utf_16_le"))
     return (f"{appName}-{jobName}.zip", zipBuffer.getvalue())
